@@ -6,7 +6,7 @@ from shop_simplecategories.models import Category
 
 
 class CategoriesTestCase(TestCase):
-    def create_fixtures(self):
+    def setUp(self):
         self.category = Category()
         self.category.name = "test_category"
         self.category.save()
@@ -16,16 +16,16 @@ class CategoriesTestCase(TestCase):
         self.product.short_description = 'test'
         self.product.long_description = 'test'
         self.product.unit_price = Decimal('1.0')
-        self.product.category = self.category
         self.product.save()
+        self.product.categories.add(self.category)
         
     def test_01_category_unicode_returns_name(self):
-        self.create_fixtures()
+        #self.create_fixtures()
         ret = self.category.__unicode__()
         self.assertEqual(ret, self.category.name)
         
     def test_02_category_get_products_works(self):
-        self.create_fixtures()
+        #self.create_fixtures()
         ret = self.category.get_products()
         self.assertEqual(len(ret),1)
         cat_product = ret[0]
