@@ -11,7 +11,7 @@ urlpatterns = patterns('',
         ShopListView.as_view(model=Category),
         name='category_list'
         ),
-    url(r'^/(?P<slug>[0-9A-Za-z-_.//]+)/$',
+    url(r'^(?P<slug>[0-9A-Za-z-_.//]+)/$',
         CategoryDetailView.as_view(),
         name='category_detail'
         ),
